@@ -2,6 +2,14 @@ package WWW::FreeProxy::Look;
 
 use LWP::Simple;
 
+=head1 FUNCTIONS
+
+=head2 fetch
+
+Fetches proxy list
+
+=cut
+
 sub fetch {
 	my ($self, $callback) = @_;
 	my @lines = split /\n/, get('http://www.loo-k.info/plist.txt');
